### 開始

PDFMathTranslateは強力なPDF翻訳ツールです。このツールはさまざまな方法でインストールして使い始めることができます。

---

### インストール

1. [**Windows EXE**](./INSTALLATION_winexe.md) <small>Windows向け推奨</small>
2. [**Docker**](./INSTALLATION_docker.md) <small>Linux向け推奨</small>
3. [**uv** (a Python package manager)](./INSTALLATION_uv.md) <small>macOS向け推奨</small>

---

### 使い方

1. [**WebUI**の使用](./USAGE_webui.md)  
2. [**Zotero Plugin**の使用](https://github.com/guaguastandup/zotero-pdf2zh) (サードパーティプログラム)  
3. [**コマンドライン**の使用](./USAGE_commandline.md)

<div align="right"> 
<h6><small>このページの一部のコンテンツはGPTによって翻訳されており、エラーが含まれている可能性があります。</small></h6>